//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/SampleDesigner/ScriptPanel.h
//! @brief     Defines class SampleDesigner
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SCRIPTPANEL_H
#define BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SCRIPTPANEL_H

#include <QWidget>

class PythonSyntaxHighlighter;
class UpdateTimer;
class CautionSign;
class QShowEvent;
class QHideEvent;
class QTextEdit;
class QModelIndex;
class SampleItem;

//! Resides at the bottom of SampleView and displays a Python script.

class ScriptPanel : public QWidget {
    Q_OBJECT

public:
    explicit ScriptPanel(QWidget* parent);

    void setCurrentSample(SampleItem* sampleItem);
    void onSampleModified();

protected:
    void showEvent(QShowEvent*) override;
    void hideEvent(QHideEvent*) override;

private:
    //! generates string representing code snippet for all multi layers in the model
    QString generateCodeSnippet();

    //! Update the editor with the script content
    void updateEditor();

    QTextEdit* m_textEdit;
    PythonSyntaxHighlighter* m_highlighter;
    UpdateTimer* m_updateTimer;
    CautionSign* m_cautionSign;
    SampleItem* m_currentSample;
};

#endif // BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_SCRIPTPANEL_H
