#include "Base/Axis/PointwiseAxis.h"
#include "GUI/Model/Data/DataItem.h"
#include "GUI/Model/Data/RealItem.h"
#include "GUI/Model/Model/RealModel.h"
#include "Tests/GTestWrapper/google_test.h"
#include <QSignalSpy>

//! Checks that LinkInstrumentManager listens instrument model.

TEST(TestRealDataModel, realDataAddedRemoved)
{
    RealModel model;

    QSignalSpy spy(&model, SIGNAL(realDataAddedOrRemoved()));
    ASSERT_TRUE(spy.isValid());

    // populating model
    RealItem* item = model.insertIntensityDataItem();

    // checking that a signal was emitted about the new item
    ASSERT_EQ(spy.count(), 1);

    // removing
    model.removeRealItem(item);
    ASSERT_EQ(spy.count(), 2);

    model.insertIntensityDataItem();
    ASSERT_EQ(spy.count(), 3);

    model.insertSpecularDataItem();
    ASSERT_EQ(spy.count(), 4);
}

TEST(TestRealDataModel, removeNativeData)
{
    RealModel model;

    auto* item = model.insertSpecularDataItem();
    EXPECT_EQ(item->nativeDataItem(), nullptr);

    item->initNativeData();
    EXPECT_NE(item->nativeDataItem(), nullptr);
    EXPECT_FALSE(item->hasNativeData());
    EXPECT_EQ(item->nativeDataItem()->datafield(), nullptr);

    // call remove while no output data set yet
    item->removeNativeData();
    EXPECT_NE(item->nativeDataItem(), nullptr);
    EXPECT_FALSE(item->hasNativeData());
    EXPECT_EQ(item->nativeDataItem()->datafield(), nullptr);

    // add data
    auto* oData = new Datafield{{new PointwiseAxis("qVector", std::vector<double>({1, 2}))}};
    oData->setVector(std::vector<double>({3, 4}));
    item->nativeDataItem()->setDatafield(oData); // takes ownership of odata
    EXPECT_TRUE(item->hasNativeData());
    EXPECT_NE(item->nativeDataItem()->datafield(), nullptr);

    // call remove with existing output data
    item->removeNativeData();
    EXPECT_NE(item->nativeDataItem(), nullptr);
    EXPECT_FALSE(item->hasNativeData());
    EXPECT_EQ(item->nativeDataItem()->datafield(), nullptr);
}
