//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Tests/Unit/GUI/Utils.h
//! @brief     Defines auxiliary test functions in a namespace.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2015
//! @authors   Scientific Computing Group at MLZ Garching
//
//  ************************************************************************************************

#ifndef BORNAGAIN_TESTS_UNIT_GUI_UTILS_H
#define BORNAGAIN_TESTS_UNIT_GUI_UTILS_H

#include "GUI/Support/XML/UtilXML.h"

class Datafield;
class RealItem;
class RealModel;

namespace UTest::GUI {

enum class DIM { D1 = 1, D2 = 2 };

//! Creates directory in current working directory. If such directory already exists,
//! it will be removed with all its content.
void create_dir(const QString& dir_name);

//! Creates output data array for testing purposes
std::unique_ptr<Datafield> createData(double value = 0.0, DIM n_dim = DIM::D2);

//! Creates real data item initialized with Datafield for testing purposes
RealItem* createRealData(const QString& name, RealModel& model, double value = 0.0,
                         DIM n_dim = DIM::D2);

//! Helper function to test if data are the same.
bool isTheSame(const Datafield& data1, const Datafield& data2);

//! Helper function to check if file on disk represents same data.
bool isTheSame(const QString& fileName, const Datafield& data);

} // namespace UTest::GUI

#endif // BORNAGAIN_TESTS_UNIT_GUI_UTILS_H
