//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Wrap/WinDllMacros.h
//! @brief     Defines export/import macros for global data symbols
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2015
//! @authors   Scientific Computing Group at MLZ Garching
//
//  ************************************************************************************************

#ifndef BORNAGAIN_WRAP_WINDLLMACROS_H
#define BORNAGAIN_WRAP_WINDLLMACROS_H

//! @def BA_CORE_API_
//! @brief Macro for export/import global data symbols (Windows only).
//! Relevant for Windows only.
//! In Linux/MAC, this macro is empty.
//!
//! In principle all exports are done with "export all symbols". This is defined in
//! the CMake file BornAgain/Windows.cmake:
//! @code set(CMAKE_WINDOWS_EXPORT_ALL_SYMBOLS ON) @endcode
//!
//! However, this is not sufficient for exported data symbols, see CMake documentation:
//!
//! "[...]For global data symbols, __declspec(dllimport) must still be used when compiling
//! against the code in the .dll. All other function symbols will be automatically exported
//! and imported by callers."
//!
//! For this reason, this macro still has to exist next to the named CMake
//! property.

//! @def BA_DEVICE_API_
//! @copydoc #BA_CORE_API_

#ifdef _WIN32

#ifdef BA_DEVICE_BUILD_DLL
#define BA_DEVICE_API_ __declspec(dllexport)
#else
#define BA_DEVICE_API_ __declspec(dllimport)
#endif // BA_DEVICE_BUILD_DLL

#ifdef BA_CORE_BUILD_DLL
#define BA_CORE_API_ __declspec(dllexport)
#else
#define BA_CORE_API_ __declspec(dllimport)
#endif // BA_CORE_BUILD_DLL

#endif // _WIN32

#ifndef BA_CORE_API_
#define BA_DEVICE_API_
#define BA_CORE_API_
#endif

#endif // BORNAGAIN_WRAP_WINDLLMACROS_H
